==> tencentcloud-sdk-java-3.1.268-sources.jar: com/tencentcloudapi/cfs/v20190719/models/SignUpCfsServiceResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cfs.v20190719.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class SignUpCfsServiceResponse extends AbstractModel{

    /**
    * 该用户当前 CFS 服务的状态，none 是未开通，creating 是开通中，created 是已开通
    */
    @SerializedName("CfsServiceStatus")
    @Expose
    private String CfsServiceStatus;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 该用户当前 CFS 服务的状态，none 是未开通，creating 是开通中，created 是已开通 
     * @return CfsServiceStatus 该用户当前 CFS 服务的状态，none 是未开通，creating 是开通中，created 是已开通
     */
    public String getCfsServiceStatus() {
        return this.CfsServiceStatus;
    }

    /**
     * Set 该用户当前 CFS 服务的状态，none 是未开通，creating 是开通中，created 是已开通
     * @param CfsServiceStatus 该用户当前 CFS 服务的状态，none 是未开通，creating 是开通中，created 是已开通
     */
    public void setCfsServiceStatus(String CfsServiceStatus) {
        this.CfsServiceStatus = CfsServiceStatus;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public SignUpCfsServiceResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public SignUpCfsServiceResponse(SignUpCfsServiceResponse source) {
        if (source.CfsServiceStatus != null) {
            this.CfsServiceStatus = new String(source.CfsServiceStatus);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "CfsServiceStatus", this.CfsServiceStatus);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/cfs/v20190719/models/SignUpCfsServiceResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cfs.v20190719.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class SignUpCfsServiceResponse extends AbstractModel{

    /**
    * 该用户当前 CFS 服务的状态，creating 是开通中，created 是已开通
    */
    @SerializedName("CfsServiceStatus")
    @Expose
    private String CfsServiceStatus;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 该用户当前 CFS 服务的状态，creating 是开通中，created 是已开通 
     * @return CfsServiceStatus 该用户当前 CFS 服务的状态，creating 是开通中，created 是已开通
     */
    public String getCfsServiceStatus() {
        return this.CfsServiceStatus;
    }

    /**
     * Set 该用户当前 CFS 服务的状态，creating 是开通中，created 是已开通
     * @param CfsServiceStatus 该用户当前 CFS 服务的状态，creating 是开通中，created 是已开通
     */
    public void setCfsServiceStatus(String CfsServiceStatus) {
        this.CfsServiceStatus = CfsServiceStatus;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public SignUpCfsServiceResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public SignUpCfsServiceResponse(SignUpCfsServiceResponse source) {
        if (source.CfsServiceStatus != null) {
            this.CfsServiceStatus = new String(source.CfsServiceStatus);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "CfsServiceStatus", this.CfsServiceStatus);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
